searchData={"items":[{"type":"module","title":"ExPassword.Argon2","doc":"This module implements the `ExPassword.Algorithm` behaviour to add support for Argon2 hashing algorithms.\n\nExcept for specific details about proper options and deeper details, you might looking for `ExPassword`'s\ndocumentation.","ref":"ExPassword.Argon2.html"},{"type":"function","title":"ExPassword.Argon2.get_options/1","doc":"Extracts informations from a given argon2 hash (the options used to generate it in the first place)\n\nReturns `{:error, :invalid}` if *hash* is not a valid argon2 hash else `{:ok, map}` where map is a Map which\ncontains all the parameters that permitted to compute this hash.\n\n    iex> ExPassword.Argon2.get_options(\"$argon2i$v=19$m=65536,t=4,p=2$ \")\n    {:ok, %{memory_cost: 65536, threads: 2, time_cost: 4, type: :argon2i, version: 19}}","ref":"ExPassword.Argon2.html#get_options/1"},{"type":"function","title":"ExPassword.Argon2.hash/2","doc":"Computes the hash for *password*. A salt of 16 bytes is randomly generated\nand prepended to *password* before hashing.\n\nValid options are:\n\n  * threads (also called parallelism): number of threads to use for computing the Argon2 hash\n  * time_cost (in seconds): maximum amount of time it may take to compute the Argon2 hash\n  * memory_cost (in kibibytes): maximum amount of memory that may be used to compute the Argon2 hash\n  * type:\n    + `:argon2i`: use the Argon2i hashing algorithm\n    + `:argon2id` (default and recommended): use the Argon2id hashing algorithm\n\nAn `ArgumentError` will be raised if one of the options above is invalid or if an internal error occurs.","ref":"ExPassword.Argon2.html#hash/2"},{"type":"function","title":"ExPassword.Argon2.needs_rehash?/2","doc":"Compares the options used to generate *hash* to *options* and returns `true` if they differ, which\nmeans you should rehash the password to update its hash.","ref":"ExPassword.Argon2.html#needs_rehash?/2"},{"type":"function","title":"ExPassword.Argon2.valid?/1","doc":"Returns `true` if *hash* seems to be an Argon2 hash.\n\nThis function is intended to quickly identify the algorithm which produces the given hash.\nIt does not perform extended checks like `get_options/1` nor `needs_rehash?/2` nor `verify?/2` do.","ref":"ExPassword.Argon2.html#valid?/1"},{"type":"function","title":"ExPassword.Argon2.verify?/2","doc":"Checks that a password matches the given argon2 hash\n\nAn `ArgumentError` will be raised if the hash is somehow invalid or if an internal error occurs.","ref":"ExPassword.Argon2.html#verify?/2"},{"type":"module","title":"ExPassword.Argon2.Application","doc":"","ref":"ExPassword.Argon2.Application.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}